/**
 * The MySensors Arduino library handles the wireless radio link and protocol
 * between your home built sensors/actuators and HA controller of choice.
 * The sensors forms a self healing radio network with optional repeaters. Each
 * repeater and gateway builds a routing tables in EEPROM which keeps track of the
 * network topology allowing messages to be routed to nodes.
 *
 * Created by Henrik Ekblad <henrik.ekblad@mysensors.org>
 * Copyright (C) 2013-2015 Sensnology AB
 * Full contributor list: https://github.com/mysensors/Arduino/graphs/contributors
 *
 * Documentation: http://www.mysensors.org
 * Support Forum: http://forum.mysensors.org
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation.
 *
 *******************************
 *
 * REVISION HISTORY
 * Version 1.0 - Henrik EKblad
 * Contribution by a-lurker and Anticimex,
 * Contribution by Norbert Truchsess <norbert.truchsess@t-online.de>
 * Contribution by Tomas Hozza <thozza@gmail.com>
 *
 *
 * DESCRIPTION
 * The EthernetGateway sends data received from sensors to the ethernet link.
 * The gateway also accepts input on ethernet interface, which is then sent out to the radio network.
 *
 * The GW code is designed for Arduino 328p / 16MHz.  ATmega168 does not have enough memory to run this program.
 *
 * LED purposes:
 * - To use the feature, uncomment MY_DEFAULT_xxx_LED_PIN in the sketch below
 * - RX (green) - blink fast on radio message received. In inclusion mode will blink fast only on presentation received
 * - TX (yellow) - blink fast on radio message transmitted. In inclusion mode will blink slowly
 * - ERR (red) - fast blink on error during transmission error or receive crc error
 *
 * See http://www.mysensors.org/build/ethernet_gateway for wiring instructions.
 *
 */

// Enable debug prints to serial monitor
// #define MY_DEBUG

// Enable gateway ethernet module type
#define MY_GATEWAY_W5100

// Not working with MY_SOFTSPI
//#define MY_RF24_IRQ_PIN  2 // INT0
//#define MY_RX_MESSAGE_BUFFER_FEATURE

// Enable and select radio type attached
#define MY_RADIO_NRF24
#define MY_RF24_PA_LEVEL RF24_PA_MAX
// #define MY_RF24_CHANNEL  0

#define MY_SOFTSPI
#define MY_SOFT_SPI_SCK_PIN  14 // A0
#define MY_SOFT_SPI_MOSI_PIN 15 // A1
#define MY_SOFT_SPI_MISO_PIN 16 // A2

// When W5100 is connected we have to move CE/CSN pins for NRF radio
#define MY_RF24_CE_PIN 5
#define MY_RF24_CS_PIN 6

// IP setting
#define MY_IP_ADDRESS 192,168,0,230   // Enable MY_IP_ADDRESS here if you want a static ip address (no DHCP)
#define MY_PORT 5003 // The port to keep open on node server mode / or port to contact in client mode
#define MY_IP_GATEWAY_ADDRESS 192,168,0,1 // If using static ip you can define Gateway and Subnet address as well
#define MY_IP_SUBNET_ADDRESS 255,255,255,0 // If using static ip you can define Gateway and Subnet address as well
#define MY_MAC_ADDRESS 0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0x00

// LED setting
#define MY_DEFAULT_LED_BLINK_PERIOD 300 // Set blinking period
#define MY_DEFAULT_RX_LED_PIN  A3  // Receive led pin
#define MY_DEFAULT_TX_LED_PIN  A4  // Transmit led pin
#define MY_DEFAULT_ERR_LED_PIN A5  // Error led pin

#include <Ethernet.h>
#include <MySensors.h>

void setup()
{
}

void presentation()
{
}

void loop()
{
}
